import { TickList } from '../utils/tickList';
import { TickMath } from 'src/utils';
import { RPCPool } from 'src/utils/rpcPool';
/**
 * A data provider for ticks that is backed by an in-memory array of ticks.
 */
export class RPCTickDataProvider {
    constructor(provider, poolAddress) {
        this.ticks = [];
        this.ticksInitialized = false;
        this.provider = provider;
        this.poolAddress = poolAddress;
    }
    async rpcFetchTicks() {
        await this.fetchTicks();
    }
    async getTick(tick) {
        if (!this.ticksInitialized) {
            this.fetchTicks();
            this.ticksInitialized = true;
        }
        return TickList.getTick(this.ticks, tick);
    }
    async nextInitializedTickWithinOneWord(tick, lte, tickSpacing) {
        if (!this.ticksInitialized) {
            this.fetchTicks();
            this.ticksInitialized = true;
        }
        return TickList.nextInitializedTickWithinOneWord(this.ticks, tick, lte, tickSpacing);
    }
    async fetchTicks() {
        // Get current blocknumber and Pooldata
        const blockNum = await this.provider.getBlockNumber();
        const poolData = await RPCPool.getPoolData(this.provider, this.poolAddress, blockNum);
        // Get Word Range
        const tickLower = -887272;
        const tickUpper = 887272;
        const lowerWord = TickMath.tickToWordCompressed(tickLower, poolData.tickSpacing);
        const upperWord = TickMath.tickToWordCompressed(tickUpper, poolData.tickSpacing);
        // Fetch all initialized tickIndices in word range
        const tickIndices = await RPCPool.getTickIndicesInWordRange(this.provider, poolData.address, poolData.tickSpacing, lowerWord, upperWord);
        // Fetch all initialized ticks from tickIndices
        this.ticks = await RPCPool.getAllTicks(this.provider, poolData.address, tickIndices);
    }
}
//# sourceMappingURL=rpcTickDataProvider.js.map